CA16-Cl02
open | /cms/logout |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Photos |
clickAndWait | link=Añadir foto |
clickAndWait | _save |
verifyTextPresent | Por favor, corrija los siguientes errores. |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | exact:Nombre: |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | exact:Image: |
clickAndWait | link=Terminar sesión |